/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.bmv2.api.service;

import org.onlab.util.ImmutableByteSequence;
import org.onosproject.bmv2.api.runtime.Bmv2Device;

/**
 * A listener of BMv2 packet events.
 */
public interface Bmv2PacketListener {

    /**
     * Handles a packet-in message.
     *
     * @param device    the BMv2 device that originated the message
     * @param inputPort the device port where the packet was received
     * @param reason    a reason code
     * @param tableId   the ID of table that originated this packet-in
     * @param contextId the ID of the BMv2 context where the packet-in was originated
     * @param packet    the packet raw data
     */
    void handlePacketIn(Bmv2Device device, int inputPort, long reason, int tableId, int contextId,
                        ImmutableByteSequence packet);
}
